# Naming Conventions Library

[![Build Status](https://travis-ci.org/xiancg/vfxnaming.svg?branch=master)](https://travis-ci.org/xiancg/vfxnaming)
[![Documentation Status](https://readthedocs.org/projects/naming-conventions/badge/?version=latest)](https://naming-conventions.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/xiancg/vfxnaming/badge.svg?branch=master)](https://coveralls.io/github/xiancg/vfxnaming?branch=master)

# Installation
```python
pip install vfxnaming
```

# Documentation
[Naming Conventions Docs](http://naming-conventions.rtfd.io/)

A complete suite of tools to manage naming conventions from one or more "Rule repositories". Structure naming rules with your own custom tokens. Then use the library to solve names following those rules so your naming is consistent, and also to parse metadata from exisiting names (cus a name is basically a collection of metadata, right?)

This is completely based on [Copyright (c) 2017 Cesar Saez](https://www.cesarsaez.me/) work. I highly recommend his [Website-Blog](https://www.cesarsaez.me/) and the video tutorial series on his [YouTube Channel](https://www.youtube.com/channel/UCRjk6bi_1ZQ9sL69agz0xMg) Full credits in the [Naming Conventions Docs](http://naming-conventions.rtfd.io/)